@@ -15,7 +15,7 @@ package App::annex_review_unused;
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-$App::annex_review_unused::VERSION = '0.004';
+$App::annex_review_unused::VERSION = '0.005';
 use 5.028;
 use strict;
 use warnings;
@@ -160,11 +160,10 @@ sub main {
     }
 
     if (@to_drop) {
-        _say_spaced_bullet("Will dropunused"
-              . (exists $dropunused_args{force} ? " with --force:" : ":"));
+        _say_spaced_bullet("Will dropunused with --force:");
         say "@to_drop\n";
-        $annex->annex->dropunused(\%dropunused_args, @to_drop)
-          if prompt_yn("Go ahead with this?");
+        $annex->annex->dropunused(\%dropunused_args, "--force", @to_drop)
+          if _prompt_yn("Go ahead with this?");
     }
 
     # exit value represents whether or not there are any unused files left
@@ -182,6 +181,19 @@ sub _say_bullet { _say_bold(" • ", @_) }
 
 sub _say_spaced_bullet { _say_bold("\n", " • ", @_, "\n") }
 
+sub _prompt_yn {
+    my $prompt = shift;
+    local $| = 1;
+    my $response;
+    while (1) {
+        print colored(['bold'], "$prompt ");
+        chomp(my $response = <STDIN>);
+        return 1 if lc($response) eq "y";
+        return 0 if lc($response) eq "n";
+        say "invalid response";
+    }
+}
+
 sub exit { $exit_main = shift // 0; goto EXIT_MAIN }
 
 1;
@@ -198,7 +210,7 @@ App::annex_review_unused - interactively process 'git annex unused' output
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 FUNCTIONS
 
